# also update debian/changelog
DOCRELEASE=4.3

DGDIR?=/usr/share/pve-doc-generator

ASCIIDOC_PVE?=/usr/bin/asciidoc-pve

PVE_COMMON_DOC_SOURCES=                 \
	${ASCIIDOC_PVE}			\
	attributes.txt                  \
	pve-copyright.adoc              \
	docinfo.xml

all:

attributes.txt docinfo.xml pmxcfs.8-synopsis.adoc:
	cp ${DGDIR}/$@ $@.tmp
	mv $@.tmp $@

%-opts.adoc: ${DGDIR}/gen-%-opts.pl
	${DGDIR}/gen-$*-opts.pl >$@.tmp
	mv $@.tmp $@

%.adoc: ${DGDIR}/gen-%-adoc.pl
	${DGDIR}/gen-$*-adoc.pl >$@.tmp
	mv $@.tmp $@

pveperf.1-synopsis.adoc:
	echo '*pveperf* `[PATH]`' > pveperf.1-synopsis.adoc

%.1-synopsis.adoc:
	perl -I. -e "use PVE::CLI::$(subst -,_,$*);print PVE::CLI::$(subst -,_,$*)->generate_asciidoc_synopsis();" > $@.tmp
	mv $@.tmp $@

%.8-synopsis.adoc:
	perl -I. -e "use PVE::Service::$(subst -,_,$*);print PVE::Service::$(subst -,_,$*)->generate_asciidoc_synopsis();" > $@.tmp
	mv $@.tmp $@

ifneq (${DGDIR},.)
%.adoc: ${DGDIR}/%.adoc
	cp $< $@.tmp
	mv $@.tmp $@
endif


%-plain.html: %.adoc ${PVE_COMMON_DOC_SOURCES}
	${ASCIIDOC_PVE} compile-wiki -o $@ $*.adoc

chapter-%.html: %.adoc ${PVE_COMMON_DOC_SOURCES}
	${ASCIIDOC_PVE} compile-chapter -o $@ $*.adoc

%.1: %.adoc %.1-synopsis.adoc ${PVE_COMMON_DOC_SOURCES}
	${ASCIIDOC_PVE} compile-man -o $@ $*.adoc
	test -n "$${NOVIEW}" || man -l $@

%.1.html: %.adoc %.1-synopsis.adoc ${PVE_COMMON_DOC_SOURCES}
	${ASCIIDOC_PVE} compile-man-html -o $@ $*.adoc

%.8: %.adoc %.8-synopsis.adoc ${PVE_COMMON_DOC_SOURCES}
	${ASCIIDOC_PVE} compile-man -o $@ $*.adoc
	test -n "$${NOVIEW}" || man -l $@

%.8.html: %.adoc %.8-synopsis.adoc ${PVE_COMMON_DOC_SOURCES}
	${ASCIIDOC_PVE} compile-man-html -o $@ $*.adoc

%.5: %.adoc %.5-opts.adoc ${PVE_COMMON_DOC_SOURCES}
	${ASCIIDOC_PVE} compile-man -o $@ $*.adoc
	test -n "$${NOVIEW}" || man -l $@

%.5.html: %.adoc %.5-opts.adoc ${PVE_COMMON_DOC_SOURCES}
	${ASCIIDOC_PVE} compile-man-html -o $@ $*.adoc

%.5-plain.html: %.adoc %.5-opts.adoc ${PVE_COMMON_DOC_SOURCES}
	${ASCIIDOC_PVE} compile-man-wiki -o $@ $*.adoc


.PHONY: cleanup-docgen
cleanup-docgen:
	rm -f *.xml.tmp *.1 *.5 *.8 *.adoc attributes.txt docinfo.xml
CHAPTER_LIST = \
	chapter-ha-manager.html \
	chapter-pct.html \
	chapter-pmxcfs.html \
	chapter-pve-bibliography.html \
	chapter-pve-faq.html \
	chapter-pve-firewall.html \
	chapter-pve-installation.html \
	chapter-pvecm.html \
	chapter-pvesm.html \
	chapter-pveum.html \
	chapter-qm.html \
	chapter-sysadmin.html \
	chapter-vzdump.html \
	pve-admin-guide.html

DATACENTER_CFG_ADOCDEPENDS = \
	${DATACENTER_CFG_ADOCSOURCES} \
	datacenter.cfg.5-opts.adoc

DATACENTER_CFG_ADOCSOURCES = \
	attributes.txt \
	datacenter.cfg.adoc \
	pve-copyright.adoc

GETTING_HELP_ADOCDEPENDS = \
	${GETTING_HELP_ADOCSOURCES}

GETTING_HELP_ADOCSOURCES = \
	attributes.txt \
	getting-help.adoc

HA_MANAGER_ADOCDEPENDS = \
	${HA_MANAGER_ADOCSOURCES} \
	ha-manager.1-synopsis.adoc

HA_MANAGER_ADOCSOURCES = \
	attributes.txt \
	ha-manager.adoc \
	pve-copyright.adoc

HOWTO_IMPROVE_PVE_DOCS_ADOCDEPENDS = \
	${HOWTO_IMPROVE_PVE_DOCS_ADOCSOURCES}

HOWTO_IMPROVE_PVE_DOCS_ADOCSOURCES = \
	attributes.txt \
	howto-improve-pve-docs.adoc

INDEX_ADOCDEPENDS = \
	${INDEX_ADOCSOURCES}

INDEX_ADOCSOURCES = \
	attributes.txt \
	chapter-index-table.adoc \
	index.adoc \
	man1-index-table.adoc \
	man5-index-table.adoc \
	man8-index-table.adoc

LOCAL_LVM_ADOCDEPENDS = \
	${LOCAL_LVM_ADOCSOURCES}

LOCAL_LVM_ADOCSOURCES = \
	attributes.txt \
	local-lvm.adoc

LOCAL_ZFS_ADOCDEPENDS = \
	${LOCAL_ZFS_ADOCSOURCES}

LOCAL_ZFS_ADOCSOURCES = \
	attributes.txt \
	local-zfs.adoc

MANUAL_PAGES = \
	datacenter.cfg.5 \
	ha-manager.1 \
	pct.1 \
	pct.conf.5 \
	pmxcfs.8 \
	pve-firewall.8 \
	pve-ha-crm.8 \
	pve-ha-lrm.8 \
	pveam.1 \
	pveceph.1 \
	pvecm.1 \
	pvedaemon.8 \
	pveperf.1 \
	pveproxy.8 \
	pvesm.1 \
	pvestatd.8 \
	pvesubscription.1 \
	pveum.1 \
	qm.1 \
	qm.conf.5 \
	qmrestore.1 \
	spiceproxy.8 \
	vzdump.1

MANUAL_SOURCES = \
	attributes.txt \
	datacenter.cfg.adoc \
	ha-manager.adoc \
	pct.adoc \
	pct.conf.adoc \
	pmxcfs.adoc \
	pve-copyright.adoc \
	pve-firewall-macros.adoc \
	pve-firewall.adoc \
	pve-ha-crm.adoc \
	pve-ha-lrm.adoc \
	pve-storage-dir.adoc \
	pve-storage-glusterfs.adoc \
	pve-storage-iscsi.adoc \
	pve-storage-iscsidirect.adoc \
	pve-storage-lvm.adoc \
	pve-storage-lvmthin.adoc \
	pve-storage-nfs.adoc \
	pve-storage-rbd.adoc \
	pve-storage-zfspool.adoc \
	pveam.adoc \
	pveceph.adoc \
	pvecm.adoc \
	pvedaemon.adoc \
	pveperf.adoc \
	pveproxy.adoc \
	pvesm.adoc \
	pvestatd.adoc \
	pvesubscription.adoc \
	pveum.adoc \
	qm.adoc \
	qm.conf.adoc \
	qmrestore.adoc \
	spiceproxy.adoc \
	vzdump.adoc

PCT_ADOCDEPENDS = \
	${PCT_ADOCSOURCES} \
	pct-mountpoint-opts.adoc \
	pct-network-opts.adoc \
	pct.1-synopsis.adoc \
	pct.conf.5-opts.adoc

PCT_ADOCSOURCES = \
	attributes.txt \
	pct.adoc \
	pve-copyright.adoc

PCT_CONF_ADOCDEPENDS = \
	${PCT_CONF_ADOCSOURCES} \
	pct.conf.5-opts.adoc

PCT_CONF_ADOCSOURCES = \
	attributes.txt \
	pct.conf.adoc \
	pve-copyright.adoc

PMXCFS_ADOCDEPENDS = \
	${PMXCFS_ADOCSOURCES} \
	pmxcfs.8-synopsis.adoc

PMXCFS_ADOCSOURCES = \
	attributes.txt \
	pmxcfs.adoc \
	pve-copyright.adoc

PVEAM_ADOCDEPENDS = \
	${PVEAM_ADOCSOURCES} \
	pveam.1-synopsis.adoc

PVEAM_ADOCSOURCES = \
	attributes.txt \
	pve-copyright.adoc \
	pveam.adoc

PVECEPH_ADOCDEPENDS = \
	${PVECEPH_ADOCSOURCES} \
	pveceph.1-synopsis.adoc

PVECEPH_ADOCSOURCES = \
	attributes.txt \
	pve-copyright.adoc \
	pveceph.adoc

PVECM_ADOCDEPENDS = \
	${PVECM_ADOCSOURCES} \
	pvecm.1-synopsis.adoc

PVECM_ADOCSOURCES = \
	attributes.txt \
	pve-copyright.adoc \
	pvecm.adoc

PVEDAEMON_ADOCDEPENDS = \
	${PVEDAEMON_ADOCSOURCES} \
	pvedaemon.8-synopsis.adoc

PVEDAEMON_ADOCSOURCES = \
	attributes.txt \
	pve-copyright.adoc \
	pvedaemon.adoc

PVEPERF_ADOCDEPENDS = \
	${PVEPERF_ADOCSOURCES} \
	pveperf.1-synopsis.adoc

PVEPERF_ADOCSOURCES = \
	attributes.txt \
	pveperf.adoc

PVEPROXY_ADOCDEPENDS = \
	${PVEPROXY_ADOCSOURCES} \
	pveproxy.8-synopsis.adoc

PVEPROXY_ADOCSOURCES = \
	attributes.txt \
	pve-copyright.adoc \
	pveproxy.adoc

PVESM_ADOCDEPENDS = \
	${PVESM_ADOCSOURCES} \
	pvesm.1-synopsis.adoc

PVESM_ADOCSOURCES = \
	attributes.txt \
	pve-copyright.adoc \
	pve-storage-dir.adoc \
	pve-storage-glusterfs.adoc \
	pve-storage-iscsi.adoc \
	pve-storage-iscsidirect.adoc \
	pve-storage-lvm.adoc \
	pve-storage-lvmthin.adoc \
	pve-storage-nfs.adoc \
	pve-storage-rbd.adoc \
	pve-storage-zfspool.adoc \
	pvesm.adoc

PVESTATD_ADOCDEPENDS = \
	${PVESTATD_ADOCSOURCES} \
	pvestatd.8-synopsis.adoc

PVESTATD_ADOCSOURCES = \
	attributes.txt \
	pve-copyright.adoc \
	pvestatd.adoc

PVESUBSCRIPTION_ADOCDEPENDS = \
	${PVESUBSCRIPTION_ADOCSOURCES} \
	pvesubscription.1-synopsis.adoc

PVESUBSCRIPTION_ADOCSOURCES = \
	attributes.txt \
	pve-copyright.adoc \
	pvesubscription.adoc

PVEUM_ADOCDEPENDS = \
	${PVEUM_ADOCSOURCES} \
	pveum.1-synopsis.adoc

PVEUM_ADOCSOURCES = \
	attributes.txt \
	pve-copyright.adoc \
	pveum.adoc

PVE_ADMIN_GUIDE_ADOCDEPENDS = \
	${PVE_ADMIN_GUIDE_ADOCSOURCES} \
	datacenter.cfg.5-opts.adoc \
	ha-manager.1-synopsis.adoc \
	pct-mountpoint-opts.adoc \
	pct-network-opts.adoc \
	pct.1-synopsis.adoc \
	pct.conf.5-opts.adoc \
	pmxcfs.8-synopsis.adoc \
	pve-firewall-cluster-opts.adoc \
	pve-firewall-host-opts.adoc \
	pve-firewall-rules-opts.adoc \
	pve-firewall-vm-opts.adoc \
	pve-firewall.8-synopsis.adoc \
	pve-ha-crm.8-synopsis.adoc \
	pve-ha-lrm.8-synopsis.adoc \
	pveam.1-synopsis.adoc \
	pveceph.1-synopsis.adoc \
	pvecm.1-synopsis.adoc \
	pvedaemon.8-synopsis.adoc \
	pveperf.1-synopsis.adoc \
	pveproxy.8-synopsis.adoc \
	pvesm.1-synopsis.adoc \
	pvestatd.8-synopsis.adoc \
	pvesubscription.1-synopsis.adoc \
	pveum.1-synopsis.adoc \
	qm.1-synopsis.adoc \
	qm.conf.5-opts.adoc \
	qmrestore.1-synopsis.adoc \
	spiceproxy.8-synopsis.adoc \
	vzdump.1-synopsis.adoc \
	vzdump.conf.5-opts.adoc

PVE_ADMIN_GUIDE_ADOCSOURCES = \
	GFDL.adoc \
	attributes.txt \
	datacenter.cfg.adoc \
	getting-help.adoc \
	ha-manager.adoc \
	howto-improve-pve-docs.adoc \
	local-lvm.adoc \
	local-zfs.adoc \
	pct.adoc \
	pmxcfs.adoc \
	pve-admin-guide.adoc \
	pve-bibliography.adoc \
	pve-disk-health-monitoring.adoc \
	pve-external-metric-server.adoc \
	pve-faq.adoc \
	pve-firewall-macros.adoc \
	pve-firewall.adoc \
	pve-installation.adoc \
	pve-intro.adoc \
	pve-network.adoc \
	pve-package-repos.adoc \
	pve-storage-dir.adoc \
	pve-storage-glusterfs.adoc \
	pve-storage-iscsi.adoc \
	pve-storage-iscsidirect.adoc \
	pve-storage-lvm.adoc \
	pve-storage-lvmthin.adoc \
	pve-storage-nfs.adoc \
	pve-storage-rbd.adoc \
	pve-storage-zfspool.adoc \
	pve-system-requirements.adoc \
	pve-usbstick.adoc \
	pveceph.adoc \
	pvecm.adoc \
	pvedaemon.adoc \
	pveperf.adoc \
	pveproxy.adoc \
	pvesm.adoc \
	pvestatd.adoc \
	pvesubscription.adoc \
	pveum.adoc \
	qm.adoc \
	spiceproxy.adoc \
	sysadmin.adoc \
	system-software-updates.adoc \
	system-timesync.adoc \
	vzdump.adoc

PVE_BIBLIOGRAPHY_ADOCDEPENDS = \
	${PVE_BIBLIOGRAPHY_ADOCSOURCES}

PVE_BIBLIOGRAPHY_ADOCSOURCES = \
	attributes.txt \
	pve-bibliography.adoc

PVE_DISK_HEALTH_MONITORING_ADOCDEPENDS = \
	${PVE_DISK_HEALTH_MONITORING_ADOCSOURCES}

PVE_DISK_HEALTH_MONITORING_ADOCSOURCES = \
	attributes.txt \
	pve-disk-health-monitoring.adoc

PVE_EXTERNAL_METRIC_SERVER_ADOCDEPENDS = \
	${PVE_EXTERNAL_METRIC_SERVER_ADOCSOURCES}

PVE_EXTERNAL_METRIC_SERVER_ADOCSOURCES = \
	attributes.txt \
	pve-external-metric-server.adoc

PVE_FAQ_ADOCDEPENDS = \
	${PVE_FAQ_ADOCSOURCES}

PVE_FAQ_ADOCSOURCES = \
	attributes.txt \
	pve-faq.adoc

PVE_FIREWALL_ADOCDEPENDS = \
	${PVE_FIREWALL_ADOCSOURCES} \
	pve-firewall-cluster-opts.adoc \
	pve-firewall-host-opts.adoc \
	pve-firewall-rules-opts.adoc \
	pve-firewall-vm-opts.adoc \
	pve-firewall.8-synopsis.adoc

PVE_FIREWALL_ADOCSOURCES = \
	attributes.txt \
	pve-copyright.adoc \
	pve-firewall-macros.adoc \
	pve-firewall.adoc

PVE_HA_CRM_ADOCDEPENDS = \
	${PVE_HA_CRM_ADOCSOURCES} \
	pve-ha-crm.8-synopsis.adoc

PVE_HA_CRM_ADOCSOURCES = \
	attributes.txt \
	pve-copyright.adoc \
	pve-ha-crm.adoc

PVE_HA_LRM_ADOCDEPENDS = \
	${PVE_HA_LRM_ADOCSOURCES} \
	pve-ha-lrm.8-synopsis.adoc

PVE_HA_LRM_ADOCSOURCES = \
	attributes.txt \
	pve-copyright.adoc \
	pve-ha-lrm.adoc

PVE_INSTALLATION_ADOCDEPENDS = \
	${PVE_INSTALLATION_ADOCSOURCES}

PVE_INSTALLATION_ADOCSOURCES = \
	attributes.txt \
	pve-installation.adoc \
	pve-system-requirements.adoc \
	pve-usbstick.adoc

PVE_INTRO_ADOCDEPENDS = \
	${PVE_INTRO_ADOCSOURCES}

PVE_INTRO_ADOCSOURCES = \
	attributes.txt \
	getting-help.adoc \
	howto-improve-pve-docs.adoc \
	pve-intro.adoc

PVE_NETWORK_ADOCDEPENDS = \
	${PVE_NETWORK_ADOCSOURCES}

PVE_NETWORK_ADOCSOURCES = \
	attributes.txt \
	pve-network.adoc

PVE_PACKAGE_REPOS_ADOCDEPENDS = \
	${PVE_PACKAGE_REPOS_ADOCSOURCES}

PVE_PACKAGE_REPOS_ADOCSOURCES = \
	attributes.txt \
	pve-package-repos.adoc

PVE_STORAGE_DIR_ADOCDEPENDS = \
	${PVE_STORAGE_DIR_ADOCSOURCES}

PVE_STORAGE_DIR_ADOCSOURCES = \
	attributes.txt \
	pve-storage-dir.adoc

PVE_STORAGE_GLUSTERFS_ADOCDEPENDS = \
	${PVE_STORAGE_GLUSTERFS_ADOCSOURCES}

PVE_STORAGE_GLUSTERFS_ADOCSOURCES = \
	attributes.txt \
	pve-storage-glusterfs.adoc

PVE_STORAGE_ISCSIDIRECT_ADOCDEPENDS = \
	${PVE_STORAGE_ISCSIDIRECT_ADOCSOURCES}

PVE_STORAGE_ISCSIDIRECT_ADOCSOURCES = \
	attributes.txt \
	pve-storage-iscsidirect.adoc

PVE_STORAGE_ISCSI_ADOCDEPENDS = \
	${PVE_STORAGE_ISCSI_ADOCSOURCES}

PVE_STORAGE_ISCSI_ADOCSOURCES = \
	attributes.txt \
	pve-storage-iscsi.adoc

PVE_STORAGE_LVMTHIN_ADOCDEPENDS = \
	${PVE_STORAGE_LVMTHIN_ADOCSOURCES}

PVE_STORAGE_LVMTHIN_ADOCSOURCES = \
	attributes.txt \
	pve-storage-lvmthin.adoc

PVE_STORAGE_LVM_ADOCDEPENDS = \
	${PVE_STORAGE_LVM_ADOCSOURCES}

PVE_STORAGE_LVM_ADOCSOURCES = \
	attributes.txt \
	pve-storage-lvm.adoc

PVE_STORAGE_NFS_ADOCDEPENDS = \
	${PVE_STORAGE_NFS_ADOCSOURCES}

PVE_STORAGE_NFS_ADOCSOURCES = \
	attributes.txt \
	pve-storage-nfs.adoc

PVE_STORAGE_RBD_ADOCDEPENDS = \
	${PVE_STORAGE_RBD_ADOCSOURCES}

PVE_STORAGE_RBD_ADOCSOURCES = \
	attributes.txt \
	pve-storage-rbd.adoc

PVE_STORAGE_ZFSPOOL_ADOCDEPENDS = \
	${PVE_STORAGE_ZFSPOOL_ADOCSOURCES}

PVE_STORAGE_ZFSPOOL_ADOCSOURCES = \
	attributes.txt \
	pve-storage-zfspool.adoc

PVE_SYSTEM_REQUIREMENTS_ADOCDEPENDS = \
	${PVE_SYSTEM_REQUIREMENTS_ADOCSOURCES}

PVE_SYSTEM_REQUIREMENTS_ADOCSOURCES = \
	attributes.txt \
	pve-system-requirements.adoc

PVE_USBSTICK_ADOCDEPENDS = \
	${PVE_USBSTICK_ADOCSOURCES}

PVE_USBSTICK_ADOCSOURCES = \
	attributes.txt \
	pve-usbstick.adoc

QMRESTORE_ADOCDEPENDS = \
	${QMRESTORE_ADOCSOURCES} \
	qmrestore.1-synopsis.adoc

QMRESTORE_ADOCSOURCES = \
	attributes.txt \
	pve-copyright.adoc \
	qmrestore.adoc

QM_ADOCDEPENDS = \
	${QM_ADOCSOURCES} \
	qm.1-synopsis.adoc \
	qm.conf.5-opts.adoc

QM_ADOCSOURCES = \
	attributes.txt \
	pve-copyright.adoc \
	qm.adoc

QM_CONF_ADOCDEPENDS = \
	${QM_CONF_ADOCSOURCES} \
	qm.conf.5-opts.adoc

QM_CONF_ADOCSOURCES = \
	attributes.txt \
	pve-copyright.adoc \
	qm.conf.adoc

README_ADOCDEPENDS = \
	${README_ADOCSOURCES}

README_ADOCSOURCES = \
	README.adoc \
	attributes.txt

SPICEPROXY_ADOCDEPENDS = \
	${SPICEPROXY_ADOCSOURCES} \
	spiceproxy.8-synopsis.adoc

SPICEPROXY_ADOCSOURCES = \
	attributes.txt \
	pve-copyright.adoc \
	spiceproxy.adoc

SYSADMIN_ADOCDEPENDS = \
	${SYSADMIN_ADOCSOURCES}

SYSADMIN_ADOCSOURCES = \
	attributes.txt \
	local-lvm.adoc \
	local-zfs.adoc \
	pve-disk-health-monitoring.adoc \
	pve-external-metric-server.adoc \
	pve-network.adoc \
	pve-package-repos.adoc \
	sysadmin.adoc \
	system-software-updates.adoc \
	system-timesync.adoc

SYSTEM_SOFTWARE_UPDATES_ADOCDEPENDS = \
	${SYSTEM_SOFTWARE_UPDATES_ADOCSOURCES}

SYSTEM_SOFTWARE_UPDATES_ADOCSOURCES = \
	attributes.txt \
	system-software-updates.adoc

SYSTEM_TIMESYNC_ADOCDEPENDS = \
	${SYSTEM_TIMESYNC_ADOCSOURCES}

SYSTEM_TIMESYNC_ADOCSOURCES = \
	attributes.txt \
	system-timesync.adoc

VZDUMP_ADOCDEPENDS = \
	${VZDUMP_ADOCSOURCES} \
	vzdump.1-synopsis.adoc \
	vzdump.conf.5-opts.adoc

VZDUMP_ADOCSOURCES = \
	attributes.txt \
	pve-copyright.adoc \
	vzdump.adoc

WIKI_IMPORTS = \
	datacenter.cfg.5-plain.html \
	getting-help-plain.html \
	ha-manager-plain.html \
	howto-improve-pve-docs-plain.html \
	local-lvm-plain.html \
	local-zfs-plain.html \
	pct-plain.html \
	pct.conf.5-plain.html \
	pmxcfs-plain.html \
	pve-bibliography-plain.html \
	pve-disk-health-monitoring-plain.html \
	pve-external-metric-server-plain.html \
	pve-faq-plain.html \
	pve-firewall-plain.html \
	pve-installation-plain.html \
	pve-network-plain.html \
	pve-package-repos-plain.html \
	pve-storage-dir-plain.html \
	pve-storage-glusterfs-plain.html \
	pve-storage-iscsi-plain.html \
	pve-storage-iscsidirect-plain.html \
	pve-storage-lvm-plain.html \
	pve-storage-lvmthin-plain.html \
	pve-storage-nfs-plain.html \
	pve-storage-rbd-plain.html \
	pve-storage-zfspool-plain.html \
	pve-system-requirements-plain.html \
	pve-usbstick-plain.html \
	pvecm-plain.html \
	pvesm-plain.html \
	pveum-plain.html \
	qm-plain.html \
	qm.conf.5-plain.html \
	sysadmin-plain.html \
	system-software-updates-plain.html \
	system-timesync-plain.html \
	vzdump-plain.html

chapter-ha-manager.html: ${HA_MANAGER_ADOCDEPENDS}

chapter-pct.html: ${PCT_ADOCDEPENDS}

chapter-pmxcfs.html: ${PMXCFS_ADOCDEPENDS}

chapter-pve-bibliography.html: ${PVE_BIBLIOGRAPHY_ADOCDEPENDS}

chapter-pve-faq.html: ${PVE_FAQ_ADOCDEPENDS}

chapter-pve-firewall.html: ${PVE_FIREWALL_ADOCDEPENDS}

chapter-pve-installation.html: ${PVE_INSTALLATION_ADOCDEPENDS}

chapter-pvecm.html: ${PVECM_ADOCDEPENDS}

chapter-pvesm.html: ${PVESM_ADOCDEPENDS}

chapter-pveum.html: ${PVEUM_ADOCDEPENDS}

chapter-qm.html: ${QM_ADOCDEPENDS}

chapter-sysadmin.html: ${SYSADMIN_ADOCDEPENDS}

chapter-vzdump.html: ${VZDUMP_ADOCDEPENDS}

datacenter.cfg.5: ${DATACENTER_CFG_ADOCDEPENDS}

datacenter.cfg.5-plain.html: ${DATACENTER_CFG_ADOCDEPENDS}

datacenter.cfg.5.html: ${DATACENTER_CFG_ADOCDEPENDS}

getting-help-plain.html: ${GETTING_HELP_ADOCDEPENDS}

ha-manager-plain.html: ${HA_MANAGER_ADOCDEPENDS}

ha-manager.1: ${HA_MANAGER_ADOCDEPENDS}

ha-manager.1-plain.html: ${HA_MANAGER_ADOCDEPENDS}

ha-manager.1.html: ${HA_MANAGER_ADOCDEPENDS}

howto-improve-pve-docs-plain.html: ${HOWTO_IMPROVE_PVE_DOCS_ADOCDEPENDS}

local-lvm-plain.html: ${LOCAL_LVM_ADOCDEPENDS}

local-zfs-plain.html: ${LOCAL_ZFS_ADOCDEPENDS}

pct-plain.html: ${PCT_ADOCDEPENDS}

pct.1: ${PCT_ADOCDEPENDS}

pct.1-plain.html: ${PCT_ADOCDEPENDS}

pct.1.html: ${PCT_ADOCDEPENDS}

pct.conf.5: ${PCT_CONF_ADOCDEPENDS}

pct.conf.5-plain.html: ${PCT_CONF_ADOCDEPENDS}

pct.conf.5.html: ${PCT_CONF_ADOCDEPENDS}

pmxcfs-plain.html: ${PMXCFS_ADOCDEPENDS}

pmxcfs.8: ${PMXCFS_ADOCDEPENDS}

pmxcfs.8-plain.html: ${PMXCFS_ADOCDEPENDS}

pmxcfs.8.html: ${PMXCFS_ADOCDEPENDS}

pve-admin-guide.html: ${PVE_ADMIN_GUIDE_ADOCDEPENDS}

pve-bibliography-plain.html: ${PVE_BIBLIOGRAPHY_ADOCDEPENDS}

pve-disk-health-monitoring-plain.html: ${PVE_DISK_HEALTH_MONITORING_ADOCDEPENDS}

pve-external-metric-server-plain.html: ${PVE_EXTERNAL_METRIC_SERVER_ADOCDEPENDS}

pve-faq-plain.html: ${PVE_FAQ_ADOCDEPENDS}

pve-firewall-plain.html: ${PVE_FIREWALL_ADOCDEPENDS}

pve-firewall.8: ${PVE_FIREWALL_ADOCDEPENDS}

pve-firewall.8-plain.html: ${PVE_FIREWALL_ADOCDEPENDS}

pve-firewall.8.html: ${PVE_FIREWALL_ADOCDEPENDS}

pve-ha-crm.8: ${PVE_HA_CRM_ADOCDEPENDS}

pve-ha-crm.8-plain.html: ${PVE_HA_CRM_ADOCDEPENDS}

pve-ha-crm.8.html: ${PVE_HA_CRM_ADOCDEPENDS}

pve-ha-lrm.8: ${PVE_HA_LRM_ADOCDEPENDS}

pve-ha-lrm.8-plain.html: ${PVE_HA_LRM_ADOCDEPENDS}

pve-ha-lrm.8.html: ${PVE_HA_LRM_ADOCDEPENDS}

pve-installation-plain.html: ${PVE_INSTALLATION_ADOCDEPENDS}

pve-network-plain.html: ${PVE_NETWORK_ADOCDEPENDS}

pve-package-repos-plain.html: ${PVE_PACKAGE_REPOS_ADOCDEPENDS}

pve-storage-dir-plain.html: ${PVE_STORAGE_DIR_ADOCDEPENDS}

pve-storage-glusterfs-plain.html: ${PVE_STORAGE_GLUSTERFS_ADOCDEPENDS}

pve-storage-iscsi-plain.html: ${PVE_STORAGE_ISCSI_ADOCDEPENDS}

pve-storage-iscsidirect-plain.html: ${PVE_STORAGE_ISCSIDIRECT_ADOCDEPENDS}

pve-storage-lvm-plain.html: ${PVE_STORAGE_LVM_ADOCDEPENDS}

pve-storage-lvmthin-plain.html: ${PVE_STORAGE_LVMTHIN_ADOCDEPENDS}

pve-storage-nfs-plain.html: ${PVE_STORAGE_NFS_ADOCDEPENDS}

pve-storage-rbd-plain.html: ${PVE_STORAGE_RBD_ADOCDEPENDS}

pve-storage-zfspool-plain.html: ${PVE_STORAGE_ZFSPOOL_ADOCDEPENDS}

pve-system-requirements-plain.html: ${PVE_SYSTEM_REQUIREMENTS_ADOCDEPENDS}

pve-usbstick-plain.html: ${PVE_USBSTICK_ADOCDEPENDS}

pveam.1: ${PVEAM_ADOCDEPENDS}

pveam.1-plain.html: ${PVEAM_ADOCDEPENDS}

pveam.1.html: ${PVEAM_ADOCDEPENDS}

pveceph.1: ${PVECEPH_ADOCDEPENDS}

pveceph.1-plain.html: ${PVECEPH_ADOCDEPENDS}

pveceph.1.html: ${PVECEPH_ADOCDEPENDS}

pvecm-plain.html: ${PVECM_ADOCDEPENDS}

pvecm.1: ${PVECM_ADOCDEPENDS}

pvecm.1-plain.html: ${PVECM_ADOCDEPENDS}

pvecm.1.html: ${PVECM_ADOCDEPENDS}

pvedaemon.8: ${PVEDAEMON_ADOCDEPENDS}

pvedaemon.8-plain.html: ${PVEDAEMON_ADOCDEPENDS}

pvedaemon.8.html: ${PVEDAEMON_ADOCDEPENDS}

pveperf.1: ${PVEPERF_ADOCDEPENDS}

pveperf.1-plain.html: ${PVEPERF_ADOCDEPENDS}

pveperf.1.html: ${PVEPERF_ADOCDEPENDS}

pveproxy.8: ${PVEPROXY_ADOCDEPENDS}

pveproxy.8-plain.html: ${PVEPROXY_ADOCDEPENDS}

pveproxy.8.html: ${PVEPROXY_ADOCDEPENDS}

pvesm-plain.html: ${PVESM_ADOCDEPENDS}

pvesm.1: ${PVESM_ADOCDEPENDS}

pvesm.1-plain.html: ${PVESM_ADOCDEPENDS}

pvesm.1.html: ${PVESM_ADOCDEPENDS}

pvestatd.8: ${PVESTATD_ADOCDEPENDS}

pvestatd.8-plain.html: ${PVESTATD_ADOCDEPENDS}

pvestatd.8.html: ${PVESTATD_ADOCDEPENDS}

pvesubscription.1: ${PVESUBSCRIPTION_ADOCDEPENDS}

pvesubscription.1-plain.html: ${PVESUBSCRIPTION_ADOCDEPENDS}

pvesubscription.1.html: ${PVESUBSCRIPTION_ADOCDEPENDS}

pveum-plain.html: ${PVEUM_ADOCDEPENDS}

pveum.1: ${PVEUM_ADOCDEPENDS}

pveum.1-plain.html: ${PVEUM_ADOCDEPENDS}

pveum.1.html: ${PVEUM_ADOCDEPENDS}

qm-plain.html: ${QM_ADOCDEPENDS}

qm.1: ${QM_ADOCDEPENDS}

qm.1-plain.html: ${QM_ADOCDEPENDS}

qm.1.html: ${QM_ADOCDEPENDS}

qm.conf.5: ${QM_CONF_ADOCDEPENDS}

qm.conf.5-plain.html: ${QM_CONF_ADOCDEPENDS}

qm.conf.5.html: ${QM_CONF_ADOCDEPENDS}

qmrestore.1: ${QMRESTORE_ADOCDEPENDS}

qmrestore.1-plain.html: ${QMRESTORE_ADOCDEPENDS}

qmrestore.1.html: ${QMRESTORE_ADOCDEPENDS}

spiceproxy.8: ${SPICEPROXY_ADOCDEPENDS}

spiceproxy.8-plain.html: ${SPICEPROXY_ADOCDEPENDS}

spiceproxy.8.html: ${SPICEPROXY_ADOCDEPENDS}

sysadmin-plain.html: ${SYSADMIN_ADOCDEPENDS}

system-software-updates-plain.html: ${SYSTEM_SOFTWARE_UPDATES_ADOCDEPENDS}

system-timesync-plain.html: ${SYSTEM_TIMESYNC_ADOCDEPENDS}

vzdump-plain.html: ${VZDUMP_ADOCDEPENDS}

vzdump.1: ${VZDUMP_ADOCDEPENDS}

vzdump.1-plain.html: ${VZDUMP_ADOCDEPENDS}

vzdump.1.html: ${VZDUMP_ADOCDEPENDS}

